@@ -43,10 +43,10 @@ setMethod("getName", signature = c("comment"), definition = function(x) {
 #' @rdname toString
 setMethod("toString", signature=c("comment"), definition=function(object, ...) {
   dest <- processExtraArg(args=list(...), name="dest", default="campsis")
-  if (dest=="campsis" || dest=="RxODE" || dest=="mrgsolve" || dest=="NONMEM") {
+  if (dest=="campsis" || isRxODE(dest) || dest=="mrgsolve" || dest=="NONMEM") {
     retValue <- ""
   } else {
     UnsupportedDestException()
   }
   return(retValue %>% appendComment(object, dest))
-})
\ No newline at end of file
+})
